## START: Set by rpmautospec
## (rpmautospec version 0.6.0)
## RPMAUTOSPEC: autorelease, autochangelog
%define autorelease(e:s:pb:n) %{?-p:0.}%{lua:
    release_number = 5;
    base_release_number = tonumber(rpm.expand("%{?-b*}%{!?-b:1}"));
    print(release_number + base_release_number - 1);
}%{?-e:.%{-e*}}%{?-s:.%{-s*}}%{!?-n:%{?dist}}
## END: Set by rpmautospec

Name:           python-param
Version:        2.0.2
Release:        %autorelease
Summary:        Make your Python code clearer and more reliable by declaring Parameters

License:        BSD-3-Clause
# The GitHub tarball contains documentation, examples, and tests; the PyPI
# tarball does not. See:
# https://github.com/holoviz/param/issues/219
# https://github.com/holoviz/param/issues/103
URL:            https://github.com/holoviz/param
Source:         %{url}/archive/v%{version}/param-%{version}.tar.gz

# Downstream-only: don’t fail tests on warnings
#
# This makes sense for upstream development and CI, but is too strict and
# brittle for distribution packaging.
Patch:          0001-Downstream-only-don-t-fail-tests-on-warnings.patch
# Tests: compatibility with Pandas 3.0
# https://github.com/holoviz/param/pull/905
Patch:          %{url}/pull/905.patch

# The binary package is noarch, and there is no compiled code, but we allow the
# base package to be arched due to a history of platform-dependent test
# failures.
%global debug_package %{nil}

# https://fedoraproject.org/wiki/Changes/EncourageI686LeafRemoval
ExcludeArch:    %{ix86}

BuildRequires:  python3-devel

# Additional test dependencies from the tests-full extra. We can’t use it
# directly because it includes tests-examples dependencies, and python-nbval
# and python-panel are not packaged.
BuildRequires:  %{py3_dist numpy}
BuildRequires:  %{py3_dist pandas} > 2~~
BuildRequires:  %{py3_dist ipython}
BuildRequires:  %{py3_dist jsonschema}
# Upgrade gmpy support to gmpy2
# https://github.com/holoviz/param/issues/661
# BuildRequires:  %%{py3_dist gmpy}
BuildRequires:  %{py3_dist cloudpickle}
BuildRequires:  %{py3_dist nest_asyncio}

%global common_description %{expand:
Param is a library providing Parameters: Python attributes extended to have
features such as type and range checking, dynamically generated values,
documentation strings, default values, etc., each of which is inherited from
parent classes if not specified in a subclass.

Documentation and examples may be found at https://param.holoviz.org.}

%description %{common_description}


%package -n python3-param
Summary:        %{summary}

BuildArch:      noarch

%py_provides python3-numbergen

# The file param/version.py is derived from a forked copy of
# https://github.com/pyviz-dev/autover. See the comments at the top of the file
# for details. Note that we cannot unbundle this library because it is in the
# public API, so the fork matters.
Provides:       bundled(python3dist(autover)) = 0.2.5

%description -n python3-param %{common_description}


# We don’t generate any “extras” metapackages:
#   - “examples” doesn’t make sense because the examples aren’t installed
#   - “doc” is only for building documentation
#   - “tests*” and “lint” are only for testing and linting, respectively
#   - “all” is for development: it contains the unwanted doc/lint/test deps.


%prep
%autosetup -n param-%{version} -p1

# https://docs.fedoraproject.org/en-US/packaging-guidelines/Python/#_linters
sed -r -i 's/^([[:blank:]]*)("coverage)/\1# \2/' pyproject.toml


%generate_buildrequires
export SETUPTOOLS_SCM_PRETEND_VERSION='%{version}'
%pyproject_buildrequires -x tests,tests-deser


%build
export SETUPTOOLS_SCM_PRETEND_VERSION='%{version}'
%pyproject_wheel


%install
%pyproject_install
%pyproject_save_files -l param numbergen


%check
# E       Failed: DID NOT RAISE <class 'Exception'>
# Not reported upstream because we can’t reproduce it in a virtualenv and
# haven’t been able to pin down a root cause.
k="${k-}${k+ and }not test_parameterized_warns_explicit_no_ref"

%ifarch s390x
# Probably either a pandas bug or a pyarrow one.
# _______________ TestFileDeserialization.test_data_frame_parquet ________________
# self = <tests.testfiledeserialization.TestFileDeserialization testMethod=test_data_frame_parquet>
#     @pd_skip
#     @parquet_skip
#     def test_data_frame_parquet(self):
#         path = '{}/val.parquet'.format(self.temp_dir)
#         P.data_frame.to_parquet(path)
# >       self._test_deserialize_array(P, path, 'data_frame')
# tests/testfiledeserialization.py:197:
# _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _
# tests/testfiledeserialization.py:99: in _test_deserialize_array
#     self.assertTrue(np.array_equal(deserialized, getattr(obj, pname)))
# E   AssertionError: False is not true
k="${k-}${k+ and }not (TestFileDeserialization and test_data_frame_parquet)"
%endif

%pytest -k "${k-}" -v


%files -n python3-param -f %{pyproject_files}
%doc README.md


%changelog
## START: Generated by rpmautospec
* Tue Feb 27 2024 Benjamin A. Beasley <code@musicinmybrain.net> - 2.0.2-5
- Patch tests for Pandas 3

* Tue Feb 27 2024 Benjamin A. Beasley <code@musicinmybrain.net> - 2.0.2-4
- Update test skips for Pandas 2

* Fri Jan 26 2024 Fedora Release Engineering <releng@fedoraproject.org> - 2.0.2-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_40_Mass_Rebuild

* Mon Jan 22 2024 Fedora Release Engineering <releng@fedoraproject.org> - 2.0.2-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_40_Mass_Rebuild

* Wed Jan 17 2024 Benjamin A. Beasley <code@musicinmybrain.net> - 2.0.2-1
- Update to 2.0.2 (close RHBZ#2258824)

* Mon Dec 18 2023 Benjamin A. Beasley <code@musicinmybrain.net> - 2.0.1-3
- Assert that %%pyproject_files contains a license file

* Mon Dec 18 2023 Benjamin A. Beasley <code@musicinmybrain.net> - 2.0.1-2
- Have %%pyproject_save_files handle numbergen rather than listing it
  manually

* Thu Nov 09 2023 Benjamin A. Beasley <code@musicinmybrain.net> - 2.0.1-1
- Update to 2.0.1

* Mon Nov 06 2023 Benjamin A. Beasley <code@musicinmybrain.net> - 2.0.0-4
- Improved patch for “doc” installed in site-packages

* Fri Nov 03 2023 Benjamin A. Beasley <code@musicinmybrain.net> - 2.0.0-3
- Skip a failing test on s390x

* Fri Nov 03 2023 Benjamin A. Beasley <code@musicinmybrain.net> - 2.0.0-2
- Assume we will never build the documentation

* Fri Nov 03 2023 Benjamin A. Beasley <code@musicinmybrain.net> - 2.0.0-1
- Update to 2.0.0 (close RHBZ#2245873)

* Fri Jul 21 2023 Fedora Release Engineering <releng@fedoraproject.org> - 1.13.0-9
- Rebuilt for https://fedoraproject.org/wiki/Fedora_39_Mass_Rebuild

* Tue Jul 11 2023 Benjamin A. Beasley <code@musicinmybrain.net> - 1.13.0-8
- Use trailing slashes for directories in files lists

* Fri Jul 07 2023 Benjamin A. Beasley <code@musicinmybrain.net> - 1.13.0-7
- Use new (rpm 4.17.1+) bcond style

* Tue Jun 13 2023 Python Maint <python-maint@redhat.com> - 1.13.0-5
- Rebuilt for Python 3.12

* Sat Jun 03 2023 Benjamin A. Beasley <code@musicinmybrain.net> - 1.13.0-4
- Remove explicit %%set_build_flags, not needed since F36 > >
  https://www.fedoraproject.org/wiki/Changes/SetBuildFlagsBuildCheck

* Sat Mar 18 2023 Benjamin A. Beasley <code@musicinmybrain.net> - 1.13.0-2
- Don’t assume %%_smp_mflags is -j%%_smp_build_ncpus

* Wed Mar 15 2023 Benjamin A. Beasley <code@musicinmybrain.net> - 1.13.0-1
- Update to 1.13 (close RHBZ#2178047)

* Fri Jan 20 2023 Fedora Release Engineering <releng@fedoraproject.org> - 1.12.3-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_38_Mass_Rebuild

* Mon Dec 19 2022 Benjamin A. Beasley <code@musicinmybrain.net> - 1.12.3-3
- Leaf package: remove i686 support

* Mon Dec 19 2022 Benjamin A. Beasley <code@musicinmybrain.net> - 1.12.3-2
- Indicate dirs. in files list with trailing slashes

* Fri Dec 09 2022 Benjamin A. Beasley <code@musicinmybrain.net> - 1.12.3-1
- Update to 1.12.3 (close RHBZ#2152096)

* Thu Nov 24 2022 Benjamin A. Beasley <code@musicinmybrain.net> - 1.12.2-6
- Update License to SPDX

* Wed Nov 23 2022 Benjamin A. Beasley <code@musicinmybrain.net> - 1.12.2-5
- Minor spec file typo fix

* Mon Aug 22 2022 Benjamin A. Beasley <code@musicinmybrain.net> - 1.12.2-4
- Parallelize sphinx-build

* Fri Jul 22 2022 Fedora Release Engineering <releng@fedoraproject.org> - 1.12.2-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_37_Mass_Rebuild

* Tue Jun 21 2022 Benjamin A. Beasley <code@musicinmybrain.net> - 1.12.2-2
- Bump EVR to align with F36

* Tue Jun 21 2022 Benjamin A. Beasley <code@musicinmybrain.net> - 1.12.2-1
- Update to 1.12.2 (close RHBZ#2099367)

* Fri Jun 17 2022 Benjamin A. Beasley <code@musicinmybrain.net> - 1.12.0-8
- Updated patch file for PR#608

* Tue Jun 14 2022 Benjamin A. Beasley <code@musicinmybrain.net> - 1.12.0-7
- Preserve existing Random seed behavior in Python 3.11 (fix RHBZ#2093926)

* Mon Jun 13 2022 Python Maint <python-maint@redhat.com> - 1.12.0-6
- Rebuilt for Python 3.11

* Fri Jan 21 2022 Fedora Release Engineering <releng@fedoraproject.org> - 1.12.0-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_36_Mass_Rebuild

* Fri Jan 07 2022 Benjamin A. Beasley <code@musicinmybrain.net> - 1.12.0-4
- Prefer python3dist(…) to %%%%{py3_dist …}

* Tue Dec 28 2021 Benjamin A. Beasley <code@musicinmybrain.net> - 1.12.0-3
- Do not generate test dependencies for linting or coverage

* Fri Nov 26 2021 Benjamin A. Beasley <code@musicinmybrain.net> - 1.12.0-2
- Reduce LaTeX PDF build verbosity

* Mon Nov 22 2021 Benjamin A. Beasley <code@musicinmybrain.net> - 1.12.0-1
- Initial package
## END: Generated by rpmautospec
